==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/SelectGroup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DropdownGroup } from "./DropdownGroup";
import { SelectItem } from "./SelectItem";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var SelectGroup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectGroup, _super);
    function SelectGroup() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(SelectGroup.prototype, "g", {
        get: function () {
            var ret_ = this.b.l("items", function (a) { return new SelectItem(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("items", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SelectGroup.prototype, "h", {
        get: function () {
            var ret_ = this.b.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    SelectGroup.prototype.i = function () {
        this.nativeElement.disconnectedCallback();
    };
    SelectGroup.$t = markType(SelectGroup, 'SelectGroup', DropdownGroup.$);
    return SelectGroup;
}(DropdownGroup));
export { SelectGroup };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/SelectGroup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DropdownGroup } from "./DropdownGroup";
import { SelectItem } from "./SelectItem";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var SelectGroup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectGroup, _super);
    function SelectGroup() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(SelectGroup.prototype, "g", {
        get: function () {
            var ret_ = this.b.m("items", function (a) { return new SelectItem(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("items", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SelectGroup.prototype, "h", {
        get: function () {
            var ret_ = this.b.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    SelectGroup.prototype.i = function () {
        this.nativeElement.disconnectedCallback();
    };
    SelectGroup.$t = markType(SelectGroup, 'SelectGroup', DropdownGroup.$);
    return SelectGroup;
}(DropdownGroup));
export { SelectGroup };
